pick_endpoint

Function pick_endpoint 

pub fn pick_endpoint(
    addrs: &[PeerAddr],
    supported: &[Protocol],
) -> Option<Endpoint>
Pick the best endpoint from a list of peer addresses that matches one of the supported protocols. Returns the highest-priority (lowest number) matching endpoint.